==> sheepbackups-0.0.4-py3-none-any.whl: sheepcore/run.py <==
import argparse
import sys, os
import requests
from tabulate import tabulate
import yaml
import time
import shutil
import json

from boto3.session import Session

from sheepcore import VERSION, setup_logging, get_logger
from sheepcore.parser import Parser, load_config, Restore
from sheepcore.api import api_request, create_api_payload, api_ping
from sheepcore.exceptions import *
from sheepcore.upload import download
from sheepcore.utils import retrieve_backup, checklist, Checklist

def entries_lookup(prefix=None, match=None, limit=10, dataset=None):
    endpoint = 'entries/'
    
    if prefix is None:
        prefix = 'all'
    endpoint += prefix
        
    if match is not None:
        endpoint += '/' + match
    
    if limit is None:
        limit = 10
    
    if dataset is not None:
        j = dataset
    else:
        r = api_request(endpoint, limit=limit)
        j = r.json()
    table = []
    num = 1
    for result in j['entries']:
        if result['meta']:
            meta = ', '.join([ '{0}: {1}'.format(k,v) for k, v in result['meta'].items() ])
        else:
            meta = ''
            
        table.append([num, result['id'], result['prefix'], result['created_servertime'], meta])
        num += 1
    return tabulate(table, headers=['', 'uuid', 'prefix', 'date', 'meta'])
    

def run_backup(only_prefix=None):
    # Check config
    # Create temp dir
    temp_dir = os.path.join(CONFIG['backups_dir'], 'backup{0}'.format(time.time()))
    try:
        os.makedirs(temp_dir)
        os.makedirs(os.path.join(temp_dir, '_meta'))
    except:
        raise
    
    logger = setup_logging(filehandler=open(os.path.join(temp_dir, '_meta', 'backup.log'), 'w'), tag='backup')
    logger.debug('Begin logging')
    
    if only_prefix is None:
        loop = CONFIG.backups.items()
    else:
        loop = (only_prefix, CONFIG.backups[only_prefix])
        
    try:
        results = CONFIG.run_backup(temp_dir)
    except SheepAPIError as e:
        pass
    except: 
        raise
    
    # Success
    s = "Backup complete\n"
    for result in results:
        resp = result['resp']
        s += "\n    [{0}]:".format(result['req'].project)
        s += "\n        - {0} uploaded to s3 bucket {1}".format(result['fname'], result['req'].s3_bucket)
        if not resp.test:
            s += "\n        - Sheep Backups link: https://app.sheepbackups.com/entry/{0}".format(result['resp'].id)
    
    return s

def run_restore(idmatch=None):
    
    # Get information from api
    if idmatch is None:
        return 'ERROR: Provide an id to restore to'
        
    req = api_request(endpoint='entries/all/{0}'.format(idmatch))
    resp = req.json()
    if resp['_num'] != 1:
        r = "ERROR: Cannot find specified id. Please provide more characters.\n\n"
        r += entries_lookup(dataset=resp)
        return r
        
    # Ensure the prefix on the api resp is the same as one in the current config
    entry = resp['entries'][0]
    if not CONFIG.includes(entry['prefix']):
        return "ERROR: The specified backup type ({1}) was not found in the config file ({0}). This should be under the `backups` entry.\n=> Unable to perform restore.\nHelp: https://docs.sheepbackups.com/etc".format(CONFIG.path, entry['prefix'])
    
    setup_logging(filehandler=open(os.path.join('/tmp', 'sheepbackups', 'restore.log'), 'w'), tag='restore')
    
    # Unzip
    fname = download(CONFIG['backups_dir'], entry)
    filesdir = retrieve_backup(fname, entry)
    
    restore = Restore(CONFIG, entry['prefix'], filesdir, fname)
    output = restore.run()
    # Ask confirmation
    # Y = proceed, ignoring errors, n or anything else = stop
    
    # Upload restore log
    restore_log = os.path.join('/tmp', 'sheepbackups', 'restore.log')
    postdata = create_api_payload('restore', prefix=entry['prefix'], meta={'more':1}, log=restore_log)
    resp = api_request('new_restore', post=json.dumps(postdata))
    response_text = resp.content
    if resp.status_code != 200:
        print('Unable to upload log file.')
        log_link = ''
    else:
        rjson = resp.json()
        log_link = 'Your log information has been uploaded: https://app.sheepbackups.com/restores/{0}'.format(rjson['uuid'])
        
    if output == 'cancelled':
        finish_text = '\nRestore cancelled. Remove downloaded backup? [Y/n] '
    elif output == 'complete':
        finish_text = '\nRestore completed. Remove downloaded backup? [Y/n] '
    
    i = input(finish_text)
    if i == 'Y':
        restore.cleanup()
    
    # Shoudl have run, or been cancelled, do cleanup
    # Remove zip (ask)
    return 'Finished.'
    
def run_check():
    checks = []
    general_checks = []
    
    # S3 check
    sess = Session()
    if sess is None:
        msg = 's3 Connection is not working. It is possible your credentials weren\'t properly loaded.'
    else:
        msg = 's3 Connection working'
    general_checks.append(Checklist(msg=msg, ok=sess is not None, tag='general'))
    
    ping = api_ping(verbose=True)
    general_checks.append(Checklist(msg='API Connection', ok=ping['ok'], extra_note='http status: {0}'.format(ping['code']), tag='general'))
    
    checks.append(general_checks)
    
    for project, actions in CONFIG.actions.items():
        for action in actions:
            checks.append(action.check())
    
    return checklist(checks, title='Running checks')

def loader():
    
    sheep_version = '{0}.{1}.{2}'.format(*VERSION)
    
    parser = argparse.ArgumentParser(description='Sheep Backups {0}. For more information on the Python cli, visit https://docs.sheepbackups.com/python'.format(sheep_version), prog='sheep')
    parser.add_argument('action', nargs='?', help='What action to perform (backup, restore, list, check)')
    parser.add_argument('match', nargs='?', help='ID to match')
    parser.add_argument('--prefix', help='Which prefix to use when searching')
    parser.add_argument('--limit', help='Number of results returned (default 10)')
    parser.add_argument('--test', action='store_true', help='Do a test backup/restore, but don\'t actually run')
    parser.add_argument('--config', help='Path to config file (default ~/.sheepbackups/config.yaml)')
    parser.add_argument('-V', '--version', action='store_true', help='Return this version')
    
    """
    configbackup - uploads to site [scrub most data], when on site, store in versions, and also links to docs for each item
    configcheck - run through some basic checks like file exists, correct keys
    restore --only-download to just download and not actually apply
    """
    
    opts = parser.parse_args()
        
    global CONFIG    
    CONFIG = load_config(opts.config)
    
    os.environ['TEST'] = str(opts.test)
        
    if opts.action == 'backup':
        return run_backup(opts.match)
    elif opts.action == 'restore':
        return run_restore(idmatch=opts.match)
    elif opts.action == 'list':
        return entries_lookup(opts.prefix, opts.match, opts.limit)
    elif opts.action == 'config':
        return CONFIG.show_info()
    elif opts.action == 'check':
        return run_check()
    elif opts.version:
        return sheep_version
    else:
        #print('Unknown action: {0}. Possible actions: backup, restore, list'.format(opts.action))
        return parser.print_help()
   
if __name__ == "__main__":
    print(loader())

==> sheepbackups-0.0.6-py3-none-any.whl: sheepcore/run.py <==
import argparse
import sys, os
import requests
from tabulate import tabulate
import yaml
import time
import shutil
import json

from boto3.session import Session

from sheepcore import VERSION, setup_logging, get_logger
from sheepcore.parser import Parser, load_config, Restore
from sheepcore.api import api_request, create_api_payload, api_ping
from sheepcore.exceptions import *
from sheepcore.upload import download
from sheepcore.utils import retrieve_backup, checklist, Checklist, program_exists
from sheepcore.schedule import Schedule

def entries_lookup(prefix=None, match=None, limit=10, dataset=None):
    endpoint = 'entries/'
    
    if prefix is None:
        prefix = 'all'
    endpoint += prefix
        
    if match is not None:
        endpoint += '/' + match
    
    if limit is None:
        limit = 10
    
    if dataset is not None:
        j = dataset
    else:
        r = api_request(endpoint, limit=limit)
        j = r.data
    table = []
    num = 1
    for result in j['entries']:
        if result['meta']:
            meta = ', '.join([ '{0}: {1}'.format(k,v) for k, v in result['meta'].items() ])
        else:
            meta = ''
            
        table.append([num, result['id'], result['prefix'], result['created_servertime'], meta])
        num += 1
    return tabulate(table, headers=['', 'uuid', 'project', 'date', 'meta'])
    

def run_backup(only_prefix=None):
    # Check config
    # Create temp dir
    temp_dir = os.path.join(CONFIG['backups_dir'], 'backup{0}'.format(time.time()))
    try:
        os.makedirs(temp_dir)
        os.makedirs(os.path.join(temp_dir, '_meta'))
    except:
        raise
    
    logger = setup_logging(filehandler=open(os.path.join(temp_dir, '_meta', 'backup.log'), 'w'), tag='backup')
    logger.debug('Begin logging')
    
    if only_prefix is None:
        loop = CONFIG.backups.items()
    else:
        loop = (only_prefix, CONFIG.backups[only_prefix])
        
    try:
        results = CONFIG.run_backup(temp_dir)
    except SheepAPIError as e:
        pass
    except: 
        raise
    
    # Success
    s = "Backup complete\n"
    for result in results:
        resp = result['resp']
        s += "\n    [{0}]:".format(result['req'].project)
        s += "\n        - {0} uploaded to s3 bucket {1}".format(result['fname'], result['req'].s3_bucket)
        if not resp.test:
            s += "\n        - Sheep Backups link: https://app.sheepbackups.com/entry/{0}".format(result['resp'].id)
    
    s += "\n"
    return s

def run_restore(idmatch=None):
    
    # Get information from api
    if idmatch is None:
        return 'ERROR: Provide an id to restore to'
        
    req = api_request(endpoint='entries/all/{0}'.format(idmatch))
    resp = req.json()
    if resp['_num'] != 1:
        r = "ERROR: Cannot find specified id. Please provide more characters.\n\n"
        r += entries_lookup(dataset=resp)
        return r
        
    # Ensure the prefix on the api resp is the same as one in the current config
    entry = resp['entries'][0]
    if not CONFIG.includes(entry['prefix']):
        return "ERROR: The specified backup type ({1}) was not found in the config file ({0}). This should be under the `backups` entry.\n=> Unable to perform restore.\nHelp: https://docs.sheepbackups.com/etc".format(CONFIG.path, entry['prefix'])
    
    setup_logging(filehandler=open(os.path.join('/tmp', 'sheepbackups', 'restore.log'), 'w'), tag='restore')
    
    # Unzip
    fname = download(CONFIG['backups_dir'], entry)
    filesdir = retrieve_backup(fname, entry)
    
    restore = Restore(CONFIG, entry['prefix'], filesdir, fname)
    output = restore.run()
    # Ask confirmation
    # Y = proceed, ignoring errors, n or anything else = stop
    
    # Upload restore log
    restore_log = os.path.join('/tmp', 'sheepbackups', 'restore.log')
    postdata = create_api_payload('restore', prefix=entry['prefix'], meta={'more':1}, log=restore_log)
    resp = api_request('new_restore', post=json.dumps(postdata))
    response_text = resp.content
    if resp.status_code != 200:
        print('Unable to upload log file.')
        log_link = ''
    else:
        rjson = resp.json()
        log_link = 'Your log information has been uploaded: https://app.sheepbackups.com/restores/{0}'.format(rjson['uuid'])
        
    if output == 'cancelled':
        finish_text = '\nRestore cancelled. Remove downloaded backup? [Y/n] '
    elif output == 'complete':
        finish_text = '\nRestore completed. Remove downloaded backup? [Y/n] '
    
    i = input(finish_text)
    if i == 'Y':
        restore.cleanup()
    
    # Shoudl have run, or been cancelled, do cleanup
    # Remove zip (ask)
    return 'Finished.'
    
def run_check():
    checks = []
    general_checks = []
    
    # S3 check
    sess = Session()
    if sess is None:
        msg = 's3 Connection is not working. It is possible your credentials weren\'t properly loaded.'
    else:
        msg = 's3 Connection working'
    general_checks.append(Checklist(msg=msg, ok=sess is not None, tag='general'))
    
    ping = api_ping(verbose=True)
    general_checks.append(Checklist(msg='API Connection', ok=ping['ok'], extra_note='http status: {0}'.format(ping['code']), tag='general'))
    
    cron = program_exists('crontab') is not None
    general_checks.append(Checklist(msg='Crontab installed', ok=cron))
    
    checks.append(general_checks)
    
    for project, actions in CONFIG.actions.items():
        for action in actions:
            checks.append(action.check())
    
    return checklist(checks, title='Running checks')
    
def schedule(when=None):
    s = Schedule()
    
    if when is None:
        # Return schedule if found in crontab
        if s.exists:
            return 'Sheep Backups is installed.'
    else:
        return 'Sheep Backups is not set to automatically run. For more information, see here: https://docs.sheepbackups.com/to/schedule'

def loader(testopt=False):
    sheep_version = '{0}.{1}.{2}'.format(*VERSION)
    
    parser = argparse.ArgumentParser(description='Sheep Backups {0}. For more information on the Python cli, visit https://docs.sheepbackups.com/python'.format(sheep_version), prog='sheep')
    parser.add_argument('action', nargs='?', help='What action to perform (backup, restore, list, check, ping, schedule)')
    parser.add_argument('match', nargs='?', help='ID to match')
    parser.add_argument('--project', help='Which project to use when searching')
    parser.add_argument('--limit', help='Number of results returned (default 10)')
    parser.add_argument('--test', action='store_true', help='Do a test backup/restore, but don\'t actually run')
    parser.add_argument('--config', help='Path to config file (default ~/.sheepbackups/config.yaml)')
    parser.add_argument('-V', '--version', action='store_true', help='Return this version')
    
    """
    configbackup - uploads to site [scrub most data], when on site, store in versions, and also links to docs for each item
    configcheck - run through some basic checks like file exists, correct keys
    restore --only-download to just download and not actually apply
    """
    
    opts = parser.parse_args()
        
    global CONFIG    
    CONFIG = load_config(opts.config)
    
    os.environ['TEST'] = str(opts.test)
        
    if opts.action == 'backup':
        return run_backup(opts.match)
    elif opts.action == 'restore':
        return run_restore(idmatch=opts.match)
    elif opts.action == 'list':
        return entries_lookup(opts.project, opts.match, opts.limit)
    elif opts.action == 'config':
        return CONFIG.show_info()
    elif opts.action == 'check':
        return run_check()
    elif opts.action == 'ping':
        return run_ping()
    elif opts.action == 'schedule':
        return schedule(opts.match)
    elif opts.version:
        return sheep_version
        
    # Used in test suite/low level usage
    elif testopt is not False:
        if testopt == 'opts':
            return opts
        if testopt == 'config':
            return CONFIG
    else:
        #print('Unknown action: {0}. Possible actions: backup, restore, list'.format(opts.action))
        return parser.format_help()
   
if __name__ == "__main__":
    print(loader())
